@@ -319,7 +319,7 @@ class Lines(Mark):
     colors = List(trait=Color(default_value=None, allow_none=True),
                   default_value=CATEGORY10).tag(sync=True, display_name='Colors')
     fill_colors = List(trait=Color(default_value=None, allow_none=True),
-                       default_value=CATEGORY10).tag(sync=True, display_name='Fill colors')
+                       default_value=[]).tag(sync=True, display_name='Fill colors')
     stroke_width = Float(2.0).tag(sync=True, display_name='Stroke width')
     labels_visibility = Enum(['none', 'label'], default_value='none').tag(sync=True, display_name='Labels visibility')
     curves_subset = List().tag(sync=True)
@@ -487,6 +487,9 @@ class Scatter(Mark):
                    min_dim=1, max_dim=1)
     rotation = NdArray(None, allow_none=True).tag(sync=True, scaled=True,
                        rtype='Number', min_dim=1, max_dim=1)
+    hovered_style = Dict().tag(sync=True)
+    unhovered_style = Dict().tag(sync=True)
+    hovered_point = Int(None, allow_none=True).tag(sync=True)
 
     # Other attributes
     scales_metadata = Dict({
@@ -521,15 +524,30 @@ class Scatter(Mark):
     update_on_move = Bool().tag(sync=True)
 
     def __init__(self, **kwargs):
+        self._drag_start_handlers = CallbackDispatcher()
+        self._drag_handlers = CallbackDispatcher()
         self._drag_end_handlers = CallbackDispatcher()
         super(Scatter, self).__init__(**kwargs)
 
+    def on_drag_start(self, callback, remove=False):
+        self._drag_start_handlers.register_callback(callback, remove=remove)
+
+    def on_drag(self, callback, remove=False):
+        self._drag_handlers.register_callback(callback, remove=remove)
+
     def on_drag_end(self, callback, remove=False):
         self._drag_end_handlers.register_callback(callback, remove=remove)
 
     def _handle_custom_msgs(self, _, content, buffers=None):
-        if content.get('event', '') == 'drag_end':
+        event = content.get('event', '')
+
+        if event == 'drag_start':
+            self._drag_start_handlers(self, content)
+        elif event == 'drag':
+            self._drag_handlers(self, content)
+        elif event == 'drag_end':
             self._drag_end_handlers(self, content)
+
         super(Scatter, self)._handle_custom_msgs(self, content)
 
     _view_name = Unicode('Scatter').tag(sync=True)
@@ -779,11 +797,13 @@ class Label(Mark):
     text: string (default: '')
         text to be displayed
     font_size: string (default: '14px')
-        front size in px, em or ex
+        font size in px, em or ex
     font_weight: {'bold', 'normal', 'bolder'}
         font weight of the caption
     align: {'start', 'middle', 'end'}
         alignment of the text with respect to the provided location
+    enable_move: Bool
+        Enable the label to be moved by dragging
     """
     x = Float().tag(sync=True) | Date().tag(sync=True) | Unicode().tag(sync=True)  # TODO: Why could it be Unicode
     y = Float().tag(sync=True) | Date().tag(sync=True) | Unicode().tag(sync=True)
@@ -800,7 +820,8 @@ class Label(Mark):
     font_size = Unicode(default_value='14px').tag(sync=True)
     font_weight = Enum(['bold', 'normal', 'bolder'], default_value='bold').tag(sync=True)
     align = Enum(['start', 'middle', 'end'], default_value='start').tag(sync=True)
-
+    enable_move = Bool().tag(sync=True)
+    
     _view_name = Unicode('Label').tag(sync=True)
     _model_name = Unicode('LabelModel').tag(sync=True)
 
@@ -910,6 +931,14 @@ class Pie(Mark):
         start angle of the pie (from top), in degrees
     end_angle: Float (default: 360.0)
         end angle of the pie (from top), in degrees
+    display_labels: bool (default: True)
+        display the labels on the pie
+    label_color: Color or None (default: None)
+        color of the labels
+    font_size: string (default: '14px')
+        label font size in px, em or ex
+    font_weight: {'bold', 'normal', 'bolder'} (default: 'normal')
+        label font weight
 
     Data Attributes
 
@@ -952,6 +981,11 @@ class Pie(Mark):
     inner_radius = Float(0.1, min=0.0, max=float('inf')).tag(sync=True)
     start_angle = Float().tag(sync=True)
     end_angle = Float(360.0).tag(sync=True)
+    display_labels = Bool(True).tag(sync=True)
+    label_color = Color(None, allow_none=True).tag(sync=True)
+    font_size = Unicode(default_value='10px').tag(sync=True)
+    font_weight = Enum(['bold', 'normal', 'bolder'], 
+                       default_value='normal').tag(sync=True)
 
     _view_name = Unicode('Pie').tag(sync=True)
     _model_name = Unicode('PieModel').tag(sync=True)
@@ -975,8 +1009,10 @@ class Map(Mark):
 
     Attributes
     ----------
-    default_color: Color or None (default: None)
-        default color for items of the map when no color data is passed
+    colors: Dict (default: {})
+        default colors for items of the map when no color data is passed. The dictionary should be indexed by the
+        id of the element and have the corresponding colors as values. The key `default_color` controls the items
+        for which no color is specified.
     selected_styles: Dict (default: {'selected_fill': 'Red', 'selected_stroke': None, 'selected_stroke_width': 2.0})
         Dictionary containing the styles for selected subunits
     hovered_styles: Dict (default: {'hovered_fill': 'Orange', 'hovered_stroke': None, 'hovered_stroke_width': 2.0})
@@ -1014,19 +1050,19 @@ class Map(Mark):
     allow_none=True).tag(sync=True)
 
     stroke_color = Color(default_value=None, allow_none=True).tag(sync=True)
-    default_color = Color(default_value=None, allow_none=True).tag(sync=True)
+    colors = Dict().tag(sync=True, display_name='Colors')
     scales_metadata = Dict({
         'color': { 'dimension': 'color' },
         'projection': { 'dimension': 'geo' }
     }).tag(sync=True)
-    selected = List(sync=True)  # TODO: Overloaded to prevent None.
+    selected = List(allow_none=True).tag(sync=True)
     selected_styles = Dict({
         'selected_fill': 'Red',
         'selected_stroke': None,
         'selected_stroke_width': 2.0
     }).tag(sync=True)
 
-    map_data = Tuple(topo_load('WorldMapData.json')).tag(sync=True)
+    map_data = Tuple(topo_load('map_data/WorldMapData.json')).tag(sync=True)
 
     _view_name = Unicode('Map').tag(sync=True)
     _model_name = Unicode('MapModel').tag(sync=True)
