@@ -346,6 +346,71 @@ def axes(mark=None, options={}, **kwargs):
     return axes
 
 
+def grids(fig=None, value='solid'):
+    """Sets the value of the grid_lines for the axis to the passed value.
+    The default value is `solid`.
+
+    Parameters
+    ----------
+    fig: Figure or None(default: None)
+        The figure for which the axes should be edited. If the value is None,
+        the current figure is used.
+    value: {'none', 'solid', 'dashed'}
+        The display of the grid_lines
+    """
+
+    if fig is None:
+        fig = current_figure()
+    for a in fig.axes:
+        a.grid_lines = value
+
+
+def hline(level, fig=None, preserve_domain=False, **kwargs):
+    """Draws a horizontal line at the given level.
+    
+    Parameters
+    ----------
+    level: float
+        The level at which to draw the horizontal line.
+    fig: Figure or None
+        The figure to which the horizontal line is to be added.
+        If the value is None, the current figure is used.
+    preserve_domain: boolean (default: False)
+        If true, the line does not affect the domain of the 'y' scale.
+    """
+    default_colors = kwargs.pop('colors', ['dodgerblue'])
+    default_width = kwargs.pop('stroke_width', 1)
+    if fig is None:
+        fig = current_figure()
+    sc_x = fig.scale_x
+    plot([0., 1.], [level, level], scales={'x': sc_x}, preserve_domain={'x': True,
+         'y': preserve_domain}, axes=False, colors=default_colors,
+         stroke_width=default_width, update_context=False)
+
+
+def vline(level, fig=None, preserve_domain=False, **kwargs):
+    """Draws a vertical line at the given level.
+
+    Parameters
+    ----------
+    level: float
+        The level at which to draw the vertical line.
+    fig: Figure or None
+        The figure to which the vertical line is to be added.
+        If the value is None, the current figure is used.
+    preserve_domain: boolean (default: False)
+        If true, the line does not affect the domain of the 'x' scale.
+    """
+    default_colors = kwargs.pop('colors', ['dodgerblue'])
+    default_width = kwargs.pop('stroke_width', 1)
+    if fig is None:
+        fig = current_figure()
+    sc_y = fig.scale_y
+    plot([level, level], [0., 1.], scales={'y': sc_y}, preserve_domain={'x': preserve_domain,
+         'y': True}, axes=False, colors=default_colors,
+         stroke_width=default_width, update_context=False)
+
+
 def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
     """Draw the mark of specified mark type.
 
@@ -364,6 +429,7 @@ def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
     """
     fig = kwargs.pop('figure', current_figure())
     scales = kwargs.pop('scales', {})
+    update_context = kwargs.pop('update_context', True)
 
     # Going through the list of data attributes
     for name in mark_type.class_trait_names(scaled=True):
@@ -375,7 +441,8 @@ def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
             # create a scale for this.
             continue
         elif name in scales:
-            _context['scales'][dimension] = scales[name]
+            if update_context:
+                _context['scales'][dimension] = scales[name]
         # Scale has to be fetched from the conext or created as it has not
         # been passed.
         elif dimension not in _context['scales']:
@@ -390,11 +457,11 @@ def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
                                   for key in Scale.scale_types
                                   if Scale.scale_types[key].rtype == rtype and
                                   issubdtype(dtype, Scale.scale_types[key].dtype)]
-            # TODO: something better than taking the FIRST compatible
-            # scale type.
-            scales[name] = compat_scale_types[0](**options.get(name, {}))
+            sorted_scales = sorted(compat_scale_types, key=lambda x: x.precedence)
+            scales[name] = sorted_scales[-1](**options.get(name, {}))
             # Adding the scale to the conext scales
-            _context['scales'][dimension] = scales[name]
+            if update_context:
+                _context['scales'][dimension] = scales[name]
         else:
             scales[name] = _context['scales'][dimension]
 
@@ -850,8 +917,15 @@ def current_figure():
 
 
 def get_context():
-    """Used for debug only. Return the current global context dictionary."""
-    return _context
+    """Used for debug only. Return a copy of the current global context dictionary."""
+    return {k: v for k, v in _context.items()}
+
+
+def set_context(context):
+    """Sets the current global context dictionary. All the attributes to be set
+    should be set. Otherwise, it will result in unpredictable behavior."""
+    global _context
+    _context = {k: v for k, v in context.items()}
 
 
 def _fetch_axis(fig, dimension, scale):
